const prettierConfig = require('./prettier.config')

module.exports = {
  parser: 'babel-eslint',
  extends: ['plugin:jest/recommended', 'airbnb', 'prettier', 'prettier/flowtype', 'prettier/react'],
  env: {
    browser: true,
    es6: true,
    jasmine: true,
    jest: true,
    'jest/globals': true,
    mocha: true,
    node: true,
  },
  globals: {
    __DEV__: true,
    fetch: true,
    FormData: true,
    Generator: true,
    IntervalID: true,
    navigator: true,
    React$Element: true,
    SyntheticEvent: true,
    SyntheticAnimationEvent: true,
    SyntheticClipboardEvent: true,
    SyntheticCompositionEvent: true,
    SyntheticInputEvent: true,
    SyntheticUIEvent: true,
    SyntheticFocusEvent: true,
    SyntheticKeyboardEvent: true,
    SyntheticMouseEvent: true,
    SyntheticDragEvent: true,
    SyntheticWheelEvent: true,
    SyntheticTouchEvent: true,
    SyntheticTransitionEvent: true,
    XMLHttpRequest: true,
  },
  plugins: ['react', 'import', 'jest', 'flowtype', 'prettier'],
  parserOptions: {
    ecmaVersion: 2017,
    sourceType: 'module',
    ecmaFeatures: {
      jsx: true,
    },
  },
  settings: {
    flowtype: {
      onlyFilesWithFlowAnnotation: false,
    },
  },
  rules: {
    'prettier/prettier': [1, prettierConfig],
    'eol-last': 0,
    'consistent-return': 1,
    'prefer-const': 1,
    'no-var': 1,
    'spaced-comment': 1,
    'comma-dangle': 0,
    'import/no-named-as-default': 0,
    'import/prefer-default-export': 0,
    'react/jsx-filename-extension': 0,
    'react/require-default-props': 0,
    'default-case': 1,
    'global-require': 0,
    'one-var': 0,
    'no-case-declarations': 0,
    'no-debugger': 1,
    'no-empty': 1,
    'no-shadow': 0,
    'no-use-before-define': 0,
    'no-plusplus': [1, { allowForLoopAfterthoughts: true }],
    'no-unused-expressions': [1, { allowTernary: true, allowShortCircuit: true }],
    'no-underscore-dangle': [1, { allow: ['_component', '__REDUX_DEVTOOLS_EXTENSION__'] }],
    'no-unused-vars': 1,
    'react/jsx-closing-tag-location': 0,
    'react/jsx-no-bind': 1,
    'react/jsx-uses-react': 1,
    'react/jsx-uses-vars': 1,
    'react/no-did-mount-set-state': 1,
    'react/no-did-update-set-state': 1,
    'react/no-will-update-set-state': 1,
    'react/no-is-mounted': 1,
    'react/no-multi-comp': 1,
    'react/no-string-refs': 1,
    'react/prefer-stateless-function': 1,
    'react/prop-types': 1,
    'react/self-closing-comp': 1,
    'react/sort-comp': 1,
    'react/no-unused-prop-types': 1,
    'react/no-array-index-key': 1,
    'jsx-a11y/alt-text': 1,
    'jsx-a11y/img-redundant-alt': 1,
    'jsx-a11y/label-has-for': 1,
    'jsx-a11y/lang': 1,
    'jsx-a11y/no-static-element-interactions': 1,
    'jsx-a11y/no-noninteractive-element-interactions': 1,
    'jsx-a11y/iframe-has-title': 1,
    'jsx-a11y/media-has-caption': 1,
  },
}
